pub struct CustomFieldsService { /* private fields */ }custom-fields only.Expand description
Typed access to the custom-fields API v2 surface (8 operations). Obtained via
Ghl::custom_fields.
Implementations
Sourceimpl CustomFieldsService
impl CustomFieldsService
Sourcepub async fn create_custom_field(
&self,
body: &CreateCustomFieldsDTO,
) -> Result<CustomFieldSuccessfulResponseDto>
pub async fn create_custom_field( &self, body: &CreateCustomFieldsDTO, ) -> Result<CustomFieldSuccessfulResponseDto>
Create Custom Field
Create Custom Field ! Only supports Custom Objects and Company (Business) today. Will be extended to other Standard Objects in the future.
POST /custom-fields/
Requires scope: locations/customFields.write.
Sourcepub async fn create_custom_field_folder(
&self,
body: &CreateFolder,
) -> Result<ICustomFieldFolder>
pub async fn create_custom_field_folder( &self, body: &CreateFolder, ) -> Result<ICustomFieldFolder>
Create Custom Field Folder
Create Custom Field Folder ! Only supports Custom Objects and Company (Business) today. Will be extended to other Standard Objects in the future.
POST /custom-fields/folder
Requires scope: locations/customFields.write.
Sourcepub async fn delete_custom_field_folder(
&self,
id: &str,
params: &DeleteCustomFieldFolderParams,
) -> Result<CustomFolderDeleteResponseDto>
pub async fn delete_custom_field_folder( &self, id: &str, params: &DeleteCustomFieldFolderParams, ) -> Result<CustomFolderDeleteResponseDto>
Delete Custom Field Folder
Create Custom Field Folder ! Only supports Custom Objects and Company (Business) today. Will be extended to other Standard Objects in the future.
DELETE /custom-fields/folder/{id}
Requires scope: locations/customFields.write.
Sourcepub async fn update_custom_field_folder_name(
&self,
id: &str,
body: &UpdateFolder,
) -> Result<ICustomFieldFolder>
pub async fn update_custom_field_folder_name( &self, id: &str, body: &UpdateFolder, ) -> Result<ICustomFieldFolder>
Update Custom Field Folder Name
Create Custom Field Folder ! Only supports Custom Objects and Company (Business) today. Will be extended to other Standard Objects in the future.
PUT /custom-fields/folder/{id}
Requires scope: locations/customFields.write.
Sourcepub async fn get_custom_fields_by_object_key(
&self,
object_key: &str,
params: &GetCustomFieldsByObjectKeyParams,
) -> Result<CustomFieldsResponseDTO>
pub async fn get_custom_fields_by_object_key( &self, object_key: &str, params: &GetCustomFieldsByObjectKeyParams, ) -> Result<CustomFieldsResponseDTO>
Get Custom Fields By Object Key
Get Custom Fields By Object Key ! Only supports Custom Objects and Company (Business) today. Will be extended to other Standard Objects in the future.
GET /custom-fields/object-key/{objectKey}
Requires scope: locations/customFields.readonly.
Sourcepub async fn delete_custom_field_by_id(
&self,
id: &str,
) -> Result<CustomFolderDeleteResponseDto>
pub async fn delete_custom_field_by_id( &self, id: &str, ) -> Result<CustomFolderDeleteResponseDto>
Delete Custom Field By Id
Delete Custom Field By Id ! Only supports Custom Objects and Company (Business) today. Will be extended to other Standard Objects in the future.
DELETE /custom-fields/{id}
Requires scope: locations/customFields.write.
Sourcepub async fn get_custom_field_folder_by_id(
&self,
id: &str,
) -> Result<CustomFieldSuccessfulResponseDto>
pub async fn get_custom_field_folder_by_id( &self, id: &str, ) -> Result<CustomFieldSuccessfulResponseDto>
Get Custom Field / Folder By Id
Get Custom Field / Folder By Id. ! Only supports Custom Objects and Company (Business) today. Will be extended to other Standard Objects in the future.
GET /custom-fields/{id}
Requires scope: locations/customFields.readonly.
Sourcepub async fn update_custom_field_by_id(
&self,
id: &str,
body: &UpdateCustomFieldsDTO,
) -> Result<CustomFieldSuccessfulResponseDto>
pub async fn update_custom_field_by_id( &self, id: &str, body: &UpdateCustomFieldsDTO, ) -> Result<CustomFieldSuccessfulResponseDto>
Update Custom Field By Id
Update Custom Field By Id ! Only supports Custom Objects and Company (Business) today. Will be extended to other Standard Objects in the future.
PUT /custom-fields/{id}
Requires scope: locations/customFields.write.