pub struct FormsService { /* private fields */ }forms only.Expand description
Typed access to the forms API v2 surface (3 operations). Obtained via
Ghl::forms.
Implementations
Sourceimpl FormsService
impl FormsService
Sourcepub async fn get_forms(
&self,
params: &GetFormsParams,
) -> Result<FormsSuccessfulResponseDto>
pub async fn get_forms( &self, params: &GetFormsParams, ) -> Result<FormsSuccessfulResponseDto>
Get Forms
GET /forms/
Requires scope: forms.readonly.
Sourcepub async fn get_forms_submissions(
&self,
params: &GetFormsSubmissionsParams,
) -> Result<FormsSubmissionsSuccessfulResponseDto>
pub async fn get_forms_submissions( &self, params: &GetFormsSubmissionsParams, ) -> Result<FormsSubmissionsSuccessfulResponseDto>
Get Forms Submissions
GET /forms/submissions
Requires scope: forms.readonly.
Sourcepub async fn upload_files_to_custom_fields(
&self,
params: &UploadFilesToCustomFieldsParams,
body: &Value,
) -> Result<Value>
pub async fn upload_files_to_custom_fields( &self, params: &UploadFilesToCustomFieldsParams, body: &Value, ) -> Result<Value>
Upload files to custom fields
Post the necessary fields for the API to upload files. The files need to be a buffer with the key “< custom_field_id >_< file_id >”. Here custom field id is the ID of your custom field and file id is a randomly generated id (or uuid) There is support for multiple file uploads as well. Have multiple fields in the format mentioned. File size is limited to 50 MB. The allowed file types are: PDF DOCX DOC JPG JPEG PNG GIF CSV XLSX XLS MP4 MPEG ZIP RAR TXT SVG The
POST /forms/upload-custom-files
Requires scope: forms.write.