pub struct GetKnowledgeBasesParams {
pub location_id: String,
pub query: Option<String>,
pub limit: Option<f64>,
pub last_knowledge_base_id: Option<String>,
}Available on crate feature
knowledge-base only.Expand description
Query parameters for KnowledgeBaseService::get_knowledge_bases.
Fields
location_id: StringlocationId query parameter.
Required by the API.
query: Option<String>search query for knowledge base name
limit: Option<f64>Maximum number of knowledge bases to return
last_knowledge_base_id: Option<String>ID of the last knowledge base from the previous page (for pagination)
Implementations
Sourceimpl GetKnowledgeBasesParams
impl GetKnowledgeBasesParams
Sourcepub fn last_knowledge_base_id(self, v: impl Into<String>) -> Self
pub fn last_knowledge_base_id(self, v: impl Into<String>) -> Self
ID of the last knowledge base from the previous page (for pagination)