KnowledgeBaseService

Struct KnowledgeBaseService 

pub struct KnowledgeBaseService { /* private fields */ }
Available on crate feature knowledge-base only.
Typed access to the knowledge-base API v2 surface (14 operations). Obtained via Ghl::knowledge_base.

Implementations

Source

impl KnowledgeBaseService

pub async fn get_knowledge_bases( &self, params: &GetKnowledgeBasesParams, ) -> Result<GetAllKnowledgeBasesPaginatedResponseDTO>

Get all knowledge bases for a location by location Id (paginated)

GET /knowledge-bases/

pub async fn post_knowledge_bases( &self, body: &CreateKnowledgeBaseDTO, ) -> Result<CreateKnowledgeBaseResponseDTO>

Create a new knowledge base (max 15 knowledge bases per location)

POST /knowledge-bases/

pub async fn delete_trained_pages( &self, body: &DeleteWebsiteUrlRequestDTO, ) -> Result<DeleteWebsiteUrlResponseDTO>

Delete trained pages

DELETE /knowledge-bases/crawler

Get all trained page links by knowledge base

GET /knowledge-bases/crawler

pub async fn start_crawling_and_discover_pages_for_training( &self, body: &DiscoverWebsiteRequestDTO, ) -> Result<DiscoverWebsiteResponseDTO>

Start crawling and discover pages for training

POST /knowledge-bases/crawler

pub async fn get_crawling_status_for_the_latest_operation( &self, params: &GetCrawlingStatusForTheLatestOperationParams, ) -> Result<CrawlingStatusResponseDTO>

Get crawling status for the latest operation

GET /knowledge-bases/crawler/status

pub async fn post_knowledge_bases_crawler_train( &self, body: &TrainDiscoveredUrlsDTO, ) -> Result<TrainDiscoveredUrlsResponseDTO>

Train discovered website pages and ingest into the knowledge base

POST /knowledge-bases/crawler/train

pub async fn get_all_fa_qs_by_knowledge_base_with_pagination_support( &self, params: &GetAllFaQsByKnowledgeBaseWithPaginationSupportParams, ) -> Result<ListFaqsResponseDTO>

Get all FAQs by knowledge base with pagination support

Retrieves FAQs for a knowledge base. Supports pagination using limit and lastFaqId parameters.

GET /knowledge-bases/faqs

pub async fn create_a_new_faq_inside_knowledge_base( &self, body: &AddFaqDTO, ) -> Result<CreateFaqResponseDTO>

Create a new FAQ inside knowledge base

POST /knowledge-bases/faqs

pub async fn delete_an_existing_knowledge_base_faq( &self, id: &str, ) -> Result<DeleteFaqResponseDTO>

Delete an existing knowledge base FAQ

DELETE /knowledge-bases/faqs/{id}

pub async fn update_an_existing_knowledge_base_faq( &self, id: &str, body: &UpdateFaqBodyDTO, ) -> Result<UpdateFaqResponseDTO>

Update an existing knowledge base FAQ

PUT /knowledge-bases/faqs/{id}

pub async fn update_a_knowledge_base( &self, id: &str, body: &UpdateKnowledgeBaseDTO, ) -> Result<UpdateKnowledgeBaseResponseDTO>

Update a knowledge base

PUT /knowledge-bases/{id}

pub async fn delete_a_knowledge_base( &self, knowledge_base_id: &str, ) -> Result<DeleteKnowledgeBaseResponseDTO>

Delete a knowledge base

DELETE /knowledge-bases/{knowledgeBaseId}

pub async fn get_knowledge_base_by_id( &self, knowledge_base_id: &str, ) -> Result<GetKnowledgeBaseByIdResponseDTO>

Get knowledge base by ID

GET /knowledge-bases/{knowledgeBaseId}