pub struct GetObjectSchemaByKeyIdParams {
pub location_id: String,
pub fetch_properties: Option<String>,
}Available on crate feature
objects only.Expand description
Query parameters for ObjectsService::get_object_schema_by_key_id.
Fields
location_id: Stringlocation id of the sub account Required by the API.
fetch_properties: Option<String>Fetch Properties , Fetches all the standard / custom fields of the object when set to true
Implementations