ObjectsService

Struct ObjectsService 

pub struct ObjectsService { /* private fields */ }
Available on crate feature objects only.
Typed access to the objects API v2 surface (9 operations). Obtained via Ghl::objects.

Implementations

Source

impl ObjectsService

pub async fn get_all_objects_for_a_location( &self, params: &GetAllObjectsForALocationParams, ) -> Result<CustomObjectListResponseDTO>

Get all objects for a location

Get all objects for a location. Supported Objects are contact, opportunity, business and custom objects.To understand objects and records, please have a look at the documentation here : https://doc.clickup.com/8631005/d/h/87cpx-277156/93bf0c2e23177b0

GET /objects/

Requires scope: objects/schema.readonly.

pub async fn create_custom_object( &self, body: &CreateCustomObjectSchemaDTO, ) -> Result<CustomObjectResponseDTO>

Create Custom Object

Allows you to create a custom object schema. To understand objects and records, please have a look at the documentation here : https://doc.clickup.com/8631005/d/h/87cpx-277156/93bf0c2e23177b0

POST /objects/

Requires scope: objects/schema.write.

pub async fn get_object_schema_by_key_id( &self, key: &str, params: &GetObjectSchemaByKeyIdParams, ) -> Result<CustomObjectByIdResponseDTO>

Get Object Schema by key / id

Retrieve Object Schema by key or ID. This will return the schema of the custom object, including all its fields and properties. Supported objects include contact, opportunity, business and custom objects.To understand objects and records, please have a look the documentation here : https://doc.clickup.com/8631005/d/h/87cpx-277156/93bf0c2e23177b0

GET /objects/{key}

Requires scope: objects/schema.readonly.

pub async fn update_object_schema_by_key_id( &self, key: &str, body: &UpdateCustomObjectSchemaDTO, ) -> Result<CustomObjectResponseDTO>

Update Object Schema By Key / Id

Update Custom Object Schema or standard object’s like contact, opportunity, business searchable fields. To understand objects and records, please have a look at the documentation here : https://doc.clickup.com/8631005/d/h/87cpx-277156/93bf0c2e23177b0

PUT /objects/{key}

Requires scope: objects/schema.write.

pub async fn create_record( &self, schema_key: &str, body: &CreateCustomObjectRecordDto, ) -> Result<RecordByIdResponseDTO>

Create Record

Create a Custom Object Record. Supported Objects business and custom objects. Documentation Link - https://doc.clickup.com/8631005/d/h/87cpx-277156/93bf0c2e23177b0/87cpx-376296

POST /objects/{schemaKey}/records

Requires scope: objects/record.write.

pub async fn search_object_records( &self, schema_key: &str, body: &SearchRecordsBody, ) -> Result<SearchRecordResponseDTO>

Search Object Records

Supported Objects are custom objects and standard objects like “business”. Documentation Link - https://doc.clickup.com/8631005/d/h/87cpx-277156/93bf0c2e23177b0/87cpx-379336

POST /objects/{schemaKey}/records/search

Requires scope: objects/record.readonly.

pub async fn delete_record( &self, schema_key: &str, id: &str, ) -> Result<ObjectRecordDeleteResponseDTO>

Delete Record

Delete Record By Id . Supported Objects are business and custom objects.

DELETE /objects/{schemaKey}/records/{id}

pub async fn get_record_by_id( &self, schema_key: &str, id: &str, ) -> Result<RecordByIdResponseDTO>

Get Record By Id

Allows you to get a Standard Object like business and custom object record by Id

GET /objects/{schemaKey}/records/{id}

pub async fn update_record( &self, schema_key: &str, id: &str, params: &UpdateRecordParams, body: &UpdateCustomObjectRecordDto, ) -> Result<RecordByIdResponseDTO>

Update Record

Update a Custom Object Record by Id. Supported Objects are business and custom objects. Documentation Link - https://doc.clickup.com/8631005/d/h/87cpx-277156/93bf0c2e23177b0/87cpx-376296

PUT /objects/{schemaKey}/records/{id}