pub struct StoreService { /* private fields */ }store only.Expand description
Typed access to the store API v2 surface (18 operations). Obtained via
Ghl::store.
Implementations
Sourceimpl StoreService
impl StoreService
Sourcepub async fn list_shipping_carriers(
&self,
params: &ListShippingCarriersParams,
) -> Result<ListShippingCarrierResponseDto>
pub async fn list_shipping_carriers( &self, params: &ListShippingCarriersParams, ) -> Result<ListShippingCarrierResponseDto>
List Shipping Carriers
The “List Shipping Carrier” API allows to retrieve a list of shipping carrier.
GET /store/shipping-carrier
Sourcepub async fn create_shipping_carrier(
&self,
body: &CreateShippingCarrierDto,
) -> Result<CreateShippingCarrierResponseDto>
pub async fn create_shipping_carrier( &self, body: &CreateShippingCarrierDto, ) -> Result<CreateShippingCarrierResponseDto>
Create Shipping Carrier
The “Create Shipping Carrier” API allows adding a new shipping carrier.
POST /store/shipping-carrier
Sourcepub async fn delete_shipping_carrier(
&self,
shipping_carrier_id: &str,
params: &DeleteShippingCarrierParams,
) -> Result<DeleteShippingCarrierResponseDto>
pub async fn delete_shipping_carrier( &self, shipping_carrier_id: &str, params: &DeleteShippingCarrierParams, ) -> Result<DeleteShippingCarrierResponseDto>
Delete shipping carrier
Delete specific shipping carrier with Id :shippingCarrierId
DELETE /store/shipping-carrier/{shippingCarrierId}
Sourcepub async fn get_shipping_carrier(
&self,
shipping_carrier_id: &str,
params: &GetShippingCarrierParams,
) -> Result<GetShippingCarrierResponseDto>
pub async fn get_shipping_carrier( &self, shipping_carrier_id: &str, params: &GetShippingCarrierParams, ) -> Result<GetShippingCarrierResponseDto>
Get Shipping Carrier
The “List Shipping Carrier” API allows to retrieve a paginated list of shipping carrier.
GET /store/shipping-carrier/{shippingCarrierId}
Sourcepub async fn update_shipping_carrier(
&self,
shipping_carrier_id: &str,
body: &UpdateShippingCarrierDto,
) -> Result<UpdateShippingCarrierResponseDto>
pub async fn update_shipping_carrier( &self, shipping_carrier_id: &str, body: &UpdateShippingCarrierDto, ) -> Result<UpdateShippingCarrierResponseDto>
Update Shipping Carrier
The “update Shipping Carrier” API allows update a shipping carrier to the system.
PUT /store/shipping-carrier/{shippingCarrierId}
Sourcepub async fn list_shipping_zones(
&self,
params: &ListShippingZonesParams,
) -> Result<ListShippingZoneResponseDto>
pub async fn list_shipping_zones( &self, params: &ListShippingZonesParams, ) -> Result<ListShippingZoneResponseDto>
List Shipping Zones
The “List Shipping Zone” API allows to retrieve a list of shipping zone.
GET /store/shipping-zone
Sourcepub async fn create_shipping_zone(
&self,
body: &CreateShippingZoneDto,
) -> Result<CreateShippingZoneResponseDto>
pub async fn create_shipping_zone( &self, body: &CreateShippingZoneDto, ) -> Result<CreateShippingZoneResponseDto>
Create Shipping Zone
The “Create Shipping Zone” API allows adding a new shipping zone.
POST /store/shipping-zone
Sourcepub async fn get_available_shipping_rates(
&self,
body: &GetAvailableShippingRates,
) -> Result<GetAvailableShippingRatesResponseDto>
pub async fn get_available_shipping_rates( &self, body: &GetAvailableShippingRates, ) -> Result<GetAvailableShippingRatesResponseDto>
Get available shipping rates
This return available shipping rates for country based on order amount
POST /store/shipping-zone/shipping-rates
Sourcepub async fn delete_shipping_zone(
&self,
shipping_zone_id: &str,
params: &DeleteShippingZoneParams,
) -> Result<DeleteShippingZoneResponseDto>
pub async fn delete_shipping_zone( &self, shipping_zone_id: &str, params: &DeleteShippingZoneParams, ) -> Result<DeleteShippingZoneResponseDto>
Delete shipping zone
Delete specific shipping zone with Id :shippingZoneId
DELETE /store/shipping-zone/{shippingZoneId}
Sourcepub async fn get_shipping_zone(
&self,
shipping_zone_id: &str,
params: &GetShippingZoneParams,
) -> Result<GetShippingZoneResponseDto>
pub async fn get_shipping_zone( &self, shipping_zone_id: &str, params: &GetShippingZoneParams, ) -> Result<GetShippingZoneResponseDto>
Get Shipping Zone
The “List Shipping Zone” API allows to retrieve a paginated list of shipping zone.
GET /store/shipping-zone/{shippingZoneId}
Sourcepub async fn update_shipping_zone(
&self,
shipping_zone_id: &str,
body: &UpdateShippingZoneDto,
) -> Result<UpdateShippingZoneResponseDto>
pub async fn update_shipping_zone( &self, shipping_zone_id: &str, body: &UpdateShippingZoneDto, ) -> Result<UpdateShippingZoneResponseDto>
Update Shipping Zone
The “update Shipping Zone” API allows update a shipping zone to the system.
PUT /store/shipping-zone/{shippingZoneId}
Sourcepub async fn list_shipping_rates(
&self,
shipping_zone_id: &str,
params: &ListShippingRatesParams,
) -> Result<ListShippingRateResponseDto>
pub async fn list_shipping_rates( &self, shipping_zone_id: &str, params: &ListShippingRatesParams, ) -> Result<ListShippingRateResponseDto>
List Shipping Rates
The “List Shipping Rate” API allows to retrieve a list of shipping rate.
GET /store/shipping-zone/{shippingZoneId}/shipping-rate
Sourcepub async fn create_shipping_rate(
&self,
shipping_zone_id: &str,
body: &CreateShippingRateDto,
) -> Result<CreateShippingRateResponseDto>
pub async fn create_shipping_rate( &self, shipping_zone_id: &str, body: &CreateShippingRateDto, ) -> Result<CreateShippingRateResponseDto>
Create Shipping Rate
The “Create Shipping Rate” API allows adding a new shipping rate.
POST /store/shipping-zone/{shippingZoneId}/shipping-rate
Sourcepub async fn delete_shipping_rate(
&self,
shipping_zone_id: &str,
shipping_rate_id: &str,
params: &DeleteShippingRateParams,
) -> Result<DeleteShippingRateResponseDto>
pub async fn delete_shipping_rate( &self, shipping_zone_id: &str, shipping_rate_id: &str, params: &DeleteShippingRateParams, ) -> Result<DeleteShippingRateResponseDto>
Delete shipping rate
Delete specific shipping rate with Id :shippingRateId
DELETE /store/shipping-zone/{shippingZoneId}/shipping-rate/{shippingRateId}
Sourcepub async fn get_shipping_rate(
&self,
shipping_zone_id: &str,
shipping_rate_id: &str,
params: &GetShippingRateParams,
) -> Result<GetShippingRateResponseDto>
pub async fn get_shipping_rate( &self, shipping_zone_id: &str, shipping_rate_id: &str, params: &GetShippingRateParams, ) -> Result<GetShippingRateResponseDto>
Get Shipping Rate
The “List Shipping Rate” API allows to retrieve a paginated list of shipping rate.
GET /store/shipping-zone/{shippingZoneId}/shipping-rate/{shippingRateId}
Sourcepub async fn update_shipping_rate(
&self,
shipping_zone_id: &str,
shipping_rate_id: &str,
body: &UpdateShippingRateDto,
) -> Result<UpdateShippingRateResponseDto>
pub async fn update_shipping_rate( &self, shipping_zone_id: &str, shipping_rate_id: &str, body: &UpdateShippingRateDto, ) -> Result<UpdateShippingRateResponseDto>
Update Shipping Rate
The “update Shipping Rate” API allows update a shipping rate to the system.
PUT /store/shipping-zone/{shippingZoneId}/shipping-rate/{shippingRateId}
Sourcepub async fn get_store_settings(
&self,
params: &GetStoreSettingsParams,
) -> Result<GetStoreSettingResponseDto>
pub async fn get_store_settings( &self, params: &GetStoreSettingsParams, ) -> Result<GetStoreSettingResponseDto>
Get Store Settings
Get store settings by altId and altType.
GET /store/store-setting
Sourcepub async fn create_update_store_settings(
&self,
body: &CreateStoreSettingDto,
) -> Result<CreateStoreSettingResponseDto>
pub async fn create_update_store_settings( &self, body: &CreateStoreSettingDto, ) -> Result<CreateStoreSettingResponseDto>
Create/Update Store Settings
Create or update store settings by altId and altType.
POST /store/store-setting